==> linshare-core-1.8.6-src.tar.bz2: src/main/java/org/linagora/linshare/core/business/service/impl/GuestBusinessServiceImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2015 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2015. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */

package org.linagora.linshare.core.business.service.impl;

import java.util.Date;
import java.util.List;

import org.linagora.linshare.core.business.service.GuestBusinessService;
import org.linagora.linshare.core.domain.constants.SupportedLanguage;
import org.linagora.linshare.core.domain.entities.AbstractDomain;
import org.linagora.linshare.core.domain.entities.Account;
import org.linagora.linshare.core.domain.entities.AllowedContact;
import org.linagora.linshare.core.domain.entities.Guest;
import org.linagora.linshare.core.domain.entities.GuestDomain;
import org.linagora.linshare.core.domain.entities.User;
import org.linagora.linshare.core.exception.BusinessErrorCode;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.exception.TechnicalErrorCode;
import org.linagora.linshare.core.exception.TechnicalException;
import org.linagora.linshare.core.repository.AllowedContactRepository;
import org.linagora.linshare.core.repository.GuestRepository;
import org.linagora.linshare.core.repository.UserRepository;
import org.linagora.linshare.core.service.PasswordService;
import org.linagora.linshare.core.utils.HashUtils;

public class GuestBusinessServiceImpl implements GuestBusinessService {

	private final GuestRepository guestRepository;

	private final UserRepository<User> userRepository;

	private final AllowedContactRepository allowedContactRepository;

	private final PasswordService passwordService;

	public GuestBusinessServiceImpl(final GuestRepository guestRepository,
			final UserRepository<User> userRepository,
			final AllowedContactRepository allowedContactRepository,
			final PasswordService passwordService) {
		this.guestRepository = guestRepository;
		this.userRepository = userRepository;
		this.allowedContactRepository = allowedContactRepository;
		this.passwordService = passwordService;
	}

	@Override
	public Guest findByLsUuid(String lsUuid) throws BusinessException {
		Guest guest = guestRepository.findByLsUuid(lsUuid);
		if (guest != null) {
			if (guest.isRestricted()) {
				guest.addContacts(allowedContactRepository.findByOwner(guest));
			}
		}
		return guest;
	}

	@Override
	public Guest find(AbstractDomain domain, String mail)
			throws BusinessException {
		Guest guest = guestRepository.findByMailAndDomain(
				domain.getIdentifier(), mail);
		if (guest != null) {
			if (guest.isRestricted()) {
				guest.addContacts(allowedContactRepository.findByOwner(guest));
			}
		}
		return guest;
	}

	@Override
	public List<Guest> findAllMyGuests(Account owner) {
		return guestRepository.searchGuest(owner, null, null, null);
	}

	@Override
	public List<Guest> findAll() {
		List<Guest> all = guestRepository.findAll();
		for (Guest guest : all) {
			if (guest.isRestricted()) {
				guest.addContacts(allowedContactRepository.findByOwner(guest));
			}
		}
		return all;
	}

	@Override
	public List<Guest> findOutdatedGuests() {
		List<Guest> outdatedGuests = guestRepository.findOutdatedGuests();
		for (Guest guest : outdatedGuests) {
			if (guest.isRestricted()) {
				guest.addContacts(allowedContactRepository.findByOwner(guest));
			}
		}
		return outdatedGuests;
	}

	@Override
	public GuestWithMetadata create(Guest guest, Account owner,
			GuestDomain domain, Date expiryDate) throws BusinessException {
		String password = passwordService.generatePassword();
		String hashedPassword = HashUtils.hashSha1withBase64(password
				.getBytes());

		guest.setOwner(owner);
		guest.setDomain(domain);
		guest.setLocale(domain.getDefaultTapestryLocale());
		guest.setExternalMailLocale(SupportedLanguage.toLanguage(domain.getDefaultTapestryLocale()));
		guest.setPassword(hashedPassword);
		guest.setExpirationDate(expiryDate);
		Guest create = guestRepository.create(guest);
		if (create.isRestricted()) {
			for (AllowedContact c : guest.getRestrictedContacts()) {
				allowedContactRepository.create(c);
			}
		}
		return new GuestWithMetadata(password, create);
	}

	@Override
	public Guest update(Account owner, Guest guest, AbstractDomain domain)
			throws BusinessException {
		try {
			Guest entity = guestRepository.findByLsUuid(guest.getLsUuid());
			entity.setOwner(owner);
			entity.setDomain(domain);
			// fields that can not be null
			entity.setCanUpload(guest.getCanUpload());
			entity.setRestricted(guest.isRestricted());
			// fields that can be null.
			entity.setComment(guest.getComment());
			entity.setBusinessLocale(guest.getLocale());
			entity.setBusinessExternalMailLocale(guest.getExternalMailLocale());
			entity.setBusinessLastName(guest.getLastName());
			entity.setBusinessFirstName(guest.getFirstName());
			entity.setBusinessMail(guest.getMail());
			Guest update = guestRepository.update(entity);
			if (update.isRestricted()) {
				try {
					allowedContactRepository.purge(update);
				} catch (IllegalArgumentException e) {
					throw new TechnicalException(
							TechnicalErrorCode.USER_INCOHERENCE, "Guest "
									+ entity.getLsUuid()
									+ " contacts cannot be purge");
				}
				for (AllowedContact c : entity.getRestrictedContacts()) {
					allowedContactRepository.create(c);
				}
			}
			return update;
		} catch (IllegalArgumentException iae) {
			throw new BusinessException(BusinessErrorCode.GUEST_NOT_FOUND,
					"Cannot update guest " + guest);
		}
	}

	@Override
	public void delete(Guest guest) throws BusinessException {
		if (guest.isRestricted()) {
			allowedContactRepository.purge(guest);
		}
		userRepository.delete(guest);
	}

	@Override
	public boolean exist(String domainId, String mail) {
		return guestRepository.findByMailAndDomain(domainId, mail) == null;
	}

	@Override
	public GuestWithMetadata resetPassword(Guest guest)
			throws BusinessException {
		String password = passwordService.generatePassword();
		String hashedPassword = HashUtils.hashSha1withBase64(password
				.getBytes());
		guest.setPassword(hashedPassword);
		Guest update = guestRepository.update(guest);
		return new GuestWithMetadata(password, update);
	}

	/**
	 * HELPERS
	 */

	public class GuestWithMetadata {

		private final String password;

		private final Guest guest;

		public GuestWithMetadata(String password, Guest guest) {
			super();
			this.password = password;
			this.guest = guest;
		}

		public String getPassword() {
			return password;
		}

		public Guest getGuest() {
			return guest;
		}
	}
}

==> linshare-core-1.8.7-src.tar.bz2: src/main/java/org/linagora/linshare/core/business/service/impl/GuestBusinessServiceImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2015 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2015. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */

package org.linagora.linshare.core.business.service.impl;

import java.util.Date;
import java.util.List;

import org.linagora.linshare.core.business.service.GuestBusinessService;
import org.linagora.linshare.core.domain.constants.SupportedLanguage;
import org.linagora.linshare.core.domain.entities.AbstractDomain;
import org.linagora.linshare.core.domain.entities.Account;
import org.linagora.linshare.core.domain.entities.AllowedContact;
import org.linagora.linshare.core.domain.entities.Guest;
import org.linagora.linshare.core.domain.entities.GuestDomain;
import org.linagora.linshare.core.domain.entities.User;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.repository.AllowedContactRepository;
import org.linagora.linshare.core.repository.GuestRepository;
import org.linagora.linshare.core.repository.UserRepository;
import org.linagora.linshare.core.service.PasswordService;
import org.linagora.linshare.core.utils.HashUtils;

public class GuestBusinessServiceImpl implements GuestBusinessService {

	private final GuestRepository guestRepository;

	private final UserRepository<User> userRepository;

	private final AllowedContactRepository allowedContactRepository;

	private final PasswordService passwordService;

	public GuestBusinessServiceImpl(final GuestRepository guestRepository,
			final UserRepository<User> userRepository,
			final AllowedContactRepository allowedContactRepository,
			final PasswordService passwordService) {
		this.guestRepository = guestRepository;
		this.userRepository = userRepository;
		this.allowedContactRepository = allowedContactRepository;
		this.passwordService = passwordService;
	}

	@Override
	public Guest findByLsUuid(String lsUuid) throws BusinessException {
		Guest guest = guestRepository.findByLsUuid(lsUuid);
		if (guest != null) {
			if (guest.isRestricted()) {
				guest.addContacts(allowedContactRepository.findByOwner(guest));
			}
		}
		return guest;
	}

	@Override
	public Guest find(AbstractDomain domain, String mail)
			throws BusinessException {
		Guest guest = guestRepository.findByMailAndDomain(
				domain.getIdentifier(), mail);
		if (guest != null) {
			if (guest.isRestricted()) {
				guest.addContacts(allowedContactRepository.findByOwner(guest));
			}
		}
		return guest;
	}

	@Override
	public List<Guest> findAllMyGuests(Account owner) {
		return guestRepository.searchGuest(owner, null, null, null);
	}

	@Override
	public List<Guest> findAll() {
		List<Guest> all = guestRepository.findAll();
		for (Guest guest : all) {
			if (guest.isRestricted()) {
				guest.addContacts(allowedContactRepository.findByOwner(guest));
			}
		}
		return all;
	}

	@Override
	public List<Guest> findOutdatedGuests() {
		List<Guest> outdatedGuests = guestRepository.findOutdatedGuests();
		for (Guest guest : outdatedGuests) {
			if (guest.isRestricted()) {
				guest.addContacts(allowedContactRepository.findByOwner(guest));
			}
		}
		return outdatedGuests;
	}

	@Override
	public GuestWithMetadata create(Account owner, Guest guest,
			GuestDomain domain, Date expiryDate, List<User> allowedContacts)
			throws BusinessException {
		String password = passwordService.generatePassword();
		String hashedPassword = HashUtils.hashSha1withBase64(password
				.getBytes());

		guest.setOwner(owner);
		guest.setDomain(domain);
		guest.setLocale(domain.getDefaultTapestryLocale());
		guest.setExternalMailLocale(SupportedLanguage.toLanguage(domain
				.getDefaultTapestryLocale()));
		guest.setPassword(hashedPassword);
		guest.setExpirationDate(expiryDate);
		Guest create = guestRepository.create(guest);
		if (create.isRestricted()) {
			if (allowedContacts != null) {
				for (User contact : allowedContacts) {
					allowedContactRepository.create(new AllowedContact(create,
							contact));
				}
			}
		}
		return new GuestWithMetadata(password, create);
	}

	@Override
	public Guest update(Account owner, Guest entity, Guest guestDto,
			AbstractDomain domain, List<User> allowedContacts)
			throws BusinessException {
		boolean wasRestricted = entity.isRestricted();
		entity.setOwner(owner);
		entity.setDomain(domain);
		// fields that can not be null
		entity.setCanUpload(guestDto.getCanUpload());
		entity.setRestricted(guestDto.isRestricted());
		// fields that can be null.
		entity.setComment(guestDto.getComment());
		entity.setBusinessLocale(guestDto.getLocale());
		entity.setBusinessExternalMailLocale(guestDto.getExternalMailLocale());
		entity.setBusinessLastName(guestDto.getLastName());
		entity.setBusinessFirstName(guestDto.getFirstName());
		entity.setBusinessMail(guestDto.getMail());
		Guest update = guestRepository.update(entity);
		if (wasRestricted == guestDto.isRestricted()) {
			if (allowedContacts != null) {
				// update
				allowedContactRepository.purge(update);
				for (User contact : allowedContacts) {
					allowedContactRepository.create(new AllowedContact(update,
							contact));
				}
			}
		} else if (wasRestricted) {
			// not restricted anymore. purge
			allowedContactRepository.purge(update);
		} else {
			// Add
			for (User contact : allowedContacts) {
				allowedContactRepository.create(new AllowedContact(update,
						contact));
			}
		}
		return update;
	}

	@Override
	public List<AllowedContact> loadAllowedContacts(User guest)
			throws BusinessException {
		return allowedContactRepository.findByOwner(guest);
	}

	@Override
	public void delete(Guest guest) throws BusinessException {
		if (guest.isRestricted()) {
			allowedContactRepository.purge(guest);
		}
		userRepository.delete(guest);
	}

	@Override
	public boolean exist(String domainId, String mail) {
		return guestRepository.findByMailAndDomain(domainId, mail) == null;
	}

	@Override
	public GuestWithMetadata resetPassword(Guest guest)
			throws BusinessException {
		String password = passwordService.generatePassword();
		String hashedPassword = HashUtils.hashSha1withBase64(password
				.getBytes());
		guest.setPassword(hashedPassword);
		Guest update = guestRepository.update(guest);
		return new GuestWithMetadata(password, update);
	}

	@Override
	public void evict(Guest entity) {
		guestRepository.evict(entity);
	}

	/**
	 * HELPERS
	 */

	public class GuestWithMetadata {

		private final String password;

		private final Guest guest;

		public GuestWithMetadata(String password, Guest guest) {
			super();
			this.password = password;
			this.guest = guest;
		}

		public String getPassword() {
			return password;
		}

		public Guest getGuest() {
			return guest;
		}
	}
}
